
#==============================================================================#
#####    ESTADÍSTICAS DE TRANSPORTE (SINIESTROS DE TRÁNSITO) 2023          #####
#==============================================================================#
#==============================================================================#
## GENERACIÓN DE TABULADOS - ESTADÍSTICAS DE TRANSPORTE TRIMESTRAL          ####*
#==============================================================================#
#==============================================================================#
#####           INSTITUTO NACIONAL DE ESTADÍSTICA Y CENSOS (INEC)          #####*
#==============================================================================#
# FUENTE: Estadísticas de Transporte 2023.
# RESPONSABLE: Gestión de Estadísticas Estructurales (GESE).
# Fecha de elaboración: Agosto 2023.
# Fecha de Última actualización: 17/10/2023.
# ==============================================================================*
# ==============================================================================*
# Elaborado por:
# Unidad de Gestión de Estadísticas Estructurales (GESE).
# Gabriela Hidalgo
# Jenny Borja
# ==============================================================================*
# Roberto Chaves
# Jefe de Gestión de Estadísticas Estructurales (GESE)
# Instituto Nacional de Estadística y Censos
# ==============================================================================*
# Aprobado por: 
# Diana Barco
# Directora de Estadísticas Económicas (DECON)
# Instituto Nacional de Estadística y Censos 
# Diana_Barco@inec.gob.ec
# ==============================================================================*

# ==============================================================================*

######                           INSTRUCCIONES                             #####*

# 1.- Descargar la base de datos de las Estadísticas de Siniestros de Tránsito, 2023 
#     (III trimestre) en formato SPSS de la página web del INEC.
#    (https://www.ecuadorencifras.gob.ec/transporte/).

# 2.- En el disco C: de su computadora, crear una carpeta llamada "Tabulados ESTRA". 
# En esta carpeta  guardar las bases de datos (históricas) y la carpeta "Títulos tabulados",
# aquí se exportará todos los resultados en Excel (Tabulados).
# ==============================================================================*

# **************************************************************************** #
######                                NOTA                                 ##### *
#
# En este SCRIPT, se encuentra toda la programación necesaria para la generación
# de los diferentes tabulados. Estos se ha realizado en R-STUDIO. 

# **************************************************************************** #

# ============================================================================ #
######                            PASOS PREVIOS                           ######
# ============================================================================ #

##### Limpiar el espacio de trabajo #####

rm(list=ls())
cat("\014")


#==============================================================================#
# PAQUETES                                                                     #
#==============================================================================#

##### Instalacion de paquetes #####
"En caso de saltar error en la carga de librerias, instalar los paquetes quitando 
los '#' de los siguientes codigos:" 

# install.packages("tidyverse")
# install.packages("openxlsx")
# install.packages("dplyr")
# install.packages("haven")
# install.packages("stringr")
# install.packages("janitor")
# install.packages("Hmisc")

#==============================================================================#
# CARGAR LIBRERIAS                                                             #
#==============================================================================#

library(tidyverse)
library(openxlsx)
library(dplyr)
library(haven)
library(stringr)
library(janitor)
library(Hmisc)

#
#==============================================================================#
# Importar base de datos  y ruta de trabajo
#==============================================================================#

setwd("C:/Tabulados ESTRA") # Directorio de trabajo 
dir()  # Ver los documentos

#
#==============================================================================#
# Carga de bases de datos
#==============================================================================#

siniestros.III <- read_sav("2023_SINIESTROS_TRÁNSITO_BDD_IIITRIMESTRE.sav")

#==============================================================================#
#####                        CREACION DE FUNCIONES                         ##### 
#==============================================================================#

"Funcion para mover cualquier fila al inicio"
final <- function(df, row) {
  stopifnot(nrow(df) >= row) 
  rbind(df[row, ], df[-row, ])
}

"Funcion para realizar los tabulados con total de colunma al inicio"
estra <- function(df, vertical, horizontal) { 
  tab <- df %>% 
    select(all_of(c(vertical, horizontal))) %>%  
    mutate_if(is.double, as_factor) %>% 
    group_by(!!!syms(vertical),!!!syms(horizontal))%>%
    tally() %>%
    spread(horizontal, `n`)%>% 
    mutate(Total = rowSums(across(where(is.numeric)), na.rm=TRUE)) %>% 
    select(vertical,Total, everything()) %>% 
    ungroup() %>% 
    bind_rows(summarise(., across(where(is.numeric), sum, na.rm=TRUE))) %>% 
    mutate_if(is.numeric, ~replace_na(., 0)) %>%
    rename_at(-c(1:2), ~ str_to_title(.)) %>% 
    mutate_at(c(1:1), ~ str_to_title(.)) 
  return(tab)
}

# ============================================================================ #
######     CREACION DE TABULADOS PARA siniestros.III DE TRANSITO         ######
# ============================================================================ #
"En esta sección se generarán los tabulados concernientes a siniestros.III de transito (S.T.)"

##### Tabulado 1: S.T. segun mes, Enero - Septiembre por provincia #####
st1.1 <- estra(siniestros.III, vertical = "PROVINCIA", horizontal = "MES") %>% 
  complete(PROVINCIA,  fill = list(total = 0)) %>%        
  arrange(PROVINCIA) %>% 
  slice(1,2,4,3, 5:25)
st1 <- final(st1.1,nrow(st1.1))
rm(st1.1)

##### Tabulado 2: S.T. segun clase, Enero - Septiembre por provincia #####
st2.1 <- estra(siniestros.III,vertical = "PROVINCIA", horizontal = "CLASE") %>% 
  complete(PROVINCIA,  fill = list(total = 0)) %>%        
    arrange(PROVINCIA) %>% 
  slice(1,2,4,3, 5:25)
st2 <- final(st2.1,nrow(st2.1))
rm(st2.1)

##### Tabulado 3: S.T. segun meses, Enero - Septiembre por clase #####
st3.1 <- estra(siniestros.III,vertical = "CLASE", horizontal = "MES")
st3 <- final(st3.1,nrow(st3.1))
rm(st3.1)

##### Tabulado 4: S.T. segun causa, Enero - Septiembre por provincia #####
st4.1 <- estra(siniestros.III,vertical = "PROVINCIA", horizontal = "CAUSA") %>% 
  complete(PROVINCIA,  fill = list(total = 0)) %>%        
  arrange(PROVINCIA) %>% 
  slice(1,2,4,3, 5:25)
st4 <- final(st4.1,nrow(st4.1))
rm(st4.1)

##### Tabulado 5: S.T. segun meses, Enero - Septiembre por causa #####
st5.1 <- estra(siniestros.III,vertical = "CAUSA", horizontal = "MES")
st5 <- final(st5.1,nrow(st5.1))
rm(st5.1)

##### Tabulado 6: Victimas en S.T.,  por provincia #####
st6.1 <- siniestros.III %>% 
  select(PROVINCIA, TOTAL_VICTIMAS,NUM_FALLECIDO,NUM_LESIONADO) %>% 
  mutate(PROVINCIA = as_factor(PROVINCIA)) %>% 
  group_by(PROVINCIA) %>%
  summarise("Total de víctimas" = sum(TOTAL_VICTIMAS, na.rm = TRUE),
            FALLECIDOS = sum(NUM_FALLECIDO, na.rm = TRUE),
            LESIONADOS = sum(NUM_LESIONADO, na.rm = TRUE)) %>% 
  ungroup() %>% 
  complete(PROVINCIA,  fill = list(total = 0)) %>% 
  bind_rows(summarise(., across(where(is.numeric), sum, na.rm=TRUE))) %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  rename_at(-c(1:2), ~ str_to_title(.)) %>% 
  mutate_at(c(1:1), ~ str_to_title(.)) %>% 
  arrange(PROVINCIA) %>% 
  slice(1,2,4,3, 5:25)

st6 <- final(st6.1,nrow(st6.1))
rm(st6.1)

##### Tabulado 7: Victimas en S.T., por GAD municipal #####
st7.1 <- siniestros.III %>% 
  select(CANTÓN, TOTAL_VICTIMAS,NUM_FALLECIDO,NUM_LESIONADO) %>% 
  mutate(CANTÓN = as_factor(CANTÓN)) %>% 
  group_by(CANTÓN) %>%
  summarise(VÍCTIMAS= sum(TOTAL_VICTIMAS, na.rm = TRUE),
            FALLECIDOS = sum(NUM_FALLECIDO, na.rm = TRUE),
            LESIONADOS = sum(NUM_LESIONADO, na.rm = TRUE)) %>% 
  ungroup() %>% 
  complete(CANTÓN,  fill = list(total = 0)) %>% 
  mutate_if(is.numeric, ~replace_na(., 0)) %>%
  rename_at(-c(1:2), ~ str_to_title(.)) %>% 
  mutate_at(c(1:1), ~ str_to_title(.)) %>% 
  bind_rows(summarise(., across(where(is.numeric), sum, na.rm=TRUE))) 
  

st7.1 <- st7.1 %>% 
  mutate(CANTÓN=ifelse(rank(-VÍCTIMAS, ties.method = "first") <= 11, CANTÓN, 
                                  "Resto de GAD")) %>% 
  group_by(CANTÓN) %>% 
  summarise(across(everything(), sum)) %>% 
  ungroup() %>% 
  arrange(CANTÓN == "Resto de GAD", desc(VÍCTIMAS))

st7 <- final(st7.1,nrow(st7.1))
rm(st7.1)

##### Tabulado 8: S.T., fallecidos y heridos, serie historica 2014-2023 por provincia #####
"Nota: La serie historica se encuentra en los tabulados"

# ============================================================================ #
#####               DISEÑO Y EXPORTACIÓN DE TABULADOS A EXCEL              ##### 
# ============================================================================ #
"En esta sección se diseñara y exportara los tabulados en formato excel"

##### Configuracion tabulados #####
wb <- loadWorkbook("IIIT_2023_TABULADOS_DISEÑO.xlsx")

#Tabulado 1
writeData(wb,
          "1",
          st1, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "1", 
          "Total Nacional", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 2
writeData(wb,
          "2",
          st2, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "2", 
          "Total Nacional", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 3
writeData(wb,
          "3",
          st3, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "3", 
          "Total Nacional", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 4
writeData(wb,
          "4",
          st4, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "4", 
          "Total Nacional", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 5
writeData(wb,
          "5",
          st5, 
          startRow = 4, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "5", 
          "Total Nacional", 
          startCol = 1, 
          startRow = 4, 
          rowNames = FALSE)

#Tabulado 6
writeData(wb,
          "6",
          st6, 
          startRow = 3, 
          startCol = 1,  
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb, 
          "6", 
          "Total Nacional", 
          startCol = 1, 
          startRow = 3, 
          rowNames = FALSE)

#Tabulado 7
writeData(wb,
          "7",
          st7,
          startRow = 3,
          startCol = 1,
          colNames = FALSE,
          withFilter = FALSE)

writeData(wb,
          "7",
          "Total Nacional",
          startCol = 1,
          startRow = 3,
          rowNames = FALSE)

#Tabulado 8
"Nota: La serie historica se encuentra en los tabulados"


#####################   Exportación de tabulados a Excel   #####################

saveWorkbook(wb, "III_2023_TABULADOS.xlsx",overwrite = TRUE)

#####                           FIN DEL SCRIPT                             #####

